<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://https://powerfulwp.com/
 * @since      1.0.0
 *
 * @package    App_For_Delivery_Drivers
 * @subpackage App_For_Delivery_Drivers/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    App_For_Delivery_Drivers
 * @subpackage App_For_Delivery_Drivers/admin
 * @author     powerfulwp <apowerfulwp@gmail.com>
 */
class App_For_Delivery_Drivers_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in App_For_Delivery_Drivers_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The App_For_Delivery_Drivers_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/app-for-delivery-drivers-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in App_For_Delivery_Drivers_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The App_For_Delivery_Drivers_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		//wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/app-for-delivery-drivers-admin.js', array( 'jquery' ), $this->version, false );

	}
	 

	/**
	 * Plugin submenu.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function admin_menu() {
		 //add_submenu_page( 'lddfw-dashboard', esc_html( __( 'App', 'lddfw' ) ), esc_html( __( 'App', 'lddfw' ) ), 'edit_pages', 'lddfw-app', array( &$this, 'settings' ) );
	}

	 /**
	 * Display the plugin settings page.
	 *
	 * @since 1.0.0
	 */
	public function settings( $content ) {
		 
		// Retrieve account ID and token.
		$account_id    = get_option('afdd_app_account_id');  
		$account_token = get_option('afdd_app_token');  
	
		// Get site data from Freemius SDK.
		$site_data = afdd_fs()->get_site();

		// Check if site data is available.
		if ( ! $site_data ) {
			echo '<div class="notice notice-error">
			<p>' . esc_html__('Please go to the Plugins page and activate your "App for Delivery Drivers" license.', 'app-for-delivery-drivers') . '</p>
			</div>';
			return;
		}
	
		// If account token and ID exist, fetch data from the API.
		if ( $account_token && $account_id ) {
			// Fetch data from the API
			$response = wp_remote_post('https://api.powerfulwp.com/api/user/get-website-data', array(
				'method'    => 'POST',
				'body'      => json_encode(array('site_id' => $account_id)),
				'headers'   => array(
					'Content-Type'  => 'application/json',
					'Authorization' => 'Bearer ' . $account_token
				),
			));
	
			$response_body = wp_remote_retrieve_body($response);
			$website_data = json_decode($response_body, true);
	
			if ($website_data['status'] == 'success') {
				$drivers = $website_data['drivers'];
				$web_panel_url = $website_data['web_panel'];
				$account = $website_data['account'];
	
				$account_status = ($account["status"] == "1") ? "Active" : "Not active";
			} else {
				$website_data = array('status' => 'error', 'message' => __('Unable to retrieve website data.', 'app-for-delivery-drivers'));
			}
		} else {
			// No account token found.
			$website_data = array('status' => 'error', 'message' => __('No account token found.', 'app-for-delivery-drivers'));
		}
		
		// Output the settings page HTML.
		?>
		<div class="wrap">
			<h1><?php esc_html_e('App for Delivery Drivers - Account Management', 'app-for-delivery-drivers'); ?></h1>
			<?php settings_errors('afdd_messages'); // Display stored errors or success messages ?>
	
			<?php if ($website_data['status'] == 'error') : ?>
				<div class="notice notice-error">
					<p><?php echo esc_html($website_data['message']); ?></p>
				</div>
			<?php endif; ?>
	
			<!-- Top Section: Two-Column Layout -->
			<div class="afdd-top-section">
				<!-- Left Column: Drivers -->
				<?php if (isset($drivers) && !empty($drivers)) : ?>
					<div class="afdd-left-column">
						<div class="postbox afdd-drivers-card">
						<div class="inside">
							<h2  ><?php esc_html_e('Drivers', 'app-for-delivery-drivers'); ?></h2>
							 
								<p><?php esc_html_e('Below is a list of your drivers, their account statuses, and invitation details.', 'app-for-delivery-drivers'); ?></p>
								<table class="widefat fixed" cellspacing="0">
									<thead>
										<tr>
											<th><?php esc_html_e('Driver Email', 'app-for-delivery-drivers'); ?></th>
											<th><?php esc_html_e('Account Status', 'app-for-delivery-drivers'); ?></th>
											<th><?php esc_html_e('Invitation Sent', 'app-for-delivery-drivers'); ?></th>
											<th><?php esc_html_e('Date Invited', 'app-for-delivery-drivers'); ?></th>
											<th><?php esc_html_e('Actions', 'app-for-delivery-drivers'); ?></th>
										</tr>
									</thead>
									<tbody>
										<?php foreach ($drivers as $driver) : ?>
											<tr>
												<td><?php echo esc_html($driver['driver_email']); ?></td>
												<td><?php echo esc_html($driver['account_status']); ?></td>
												<td><?php echo $driver['invitation_sent'] ? esc_html__('Yes', 'app-for-delivery-drivers') : esc_html__('No', 'app-for-delivery-drivers'); ?></td>
												<td><?php echo $driver['date_invited'] ? esc_html(date_i18n(get_option('date_format'), strtotime($driver['date_invited']))) : esc_html__('N/A', 'app-for-delivery-drivers'); ?></td>
												<td>
													<?php if ($driver['account_status'] == 'No App Account') : ?>
														<?php
															// Calculate time since last invitation
															$can_resend = true;
															$time_left = '';
															if ($driver['invitation_sent'] && $driver['date_invited']) {
																$last_invitation_time = strtotime($driver['date_invited']);
																$current_time = current_time('timestamp');
																$cooldown_period = 60 * 60; // 1 hour
																$elapsed_time = $current_time - $last_invitation_time;
	
																if ($elapsed_time < $cooldown_period) {
																	$can_resend = false;
																	$time_remaining = $cooldown_period - $elapsed_time;
																	$time_left = human_time_diff($current_time, $last_invitation_time + $cooldown_period)  ;
																}
															}
														?>
														<?php if ($can_resend) : ?>
															<form method="post" action="<?php echo esc_url(admin_url('admin-post.php')); ?>">
																<?php wp_nonce_field('afdd_send_invitation_nonce', 'afdd_send_invitation_nonce_field'); ?>
																<input type="hidden" name="action" value="afdd_send_invitation">
																<input type="hidden" name="driver_email" value="<?php echo esc_attr($driver['driver_email']); ?>">
																<button type="submit" class="button"><?php esc_html_e('Send App Invitation', 'app-for-delivery-drivers'); ?></button>
															</form>
														<?php else : ?>
															<?php printf(esc_html__('You can resend in %s', 'app-for-delivery-drivers'), esc_html($time_left)); ?>
														<?php endif; ?>
													<?php else : ?>
														<span class="dashicons dashicons-yes" style="color:green;"></span>
													<?php endif; ?>
												</td>
											</tr>
										<?php endforeach; ?>
									</tbody>
								</table>
								<p><em><?php esc_html_e('Drivers must register in the app using their registered email address to sync.', 'app-for-delivery-drivers'); ?></em></p>
							</div>
						</div>
					</div>
				<?php endif; ?>
	
				<!-- Right Column: Account Management & Get the Apps -->
				<div class="afdd-right-column">
					<!-- Account Management -->
					<div class="postbox afdd-account-card">
					<div class="inside">
						<h2  ><?php esc_html_e('Account Details', 'app-for-delivery-drivers'); ?></h2>
						 
							<?php if ($account_id) { ?>
								 
							 
									<?php if (isset($account_id) && !empty($account_id)) : ?>
									
										<p><?php esc_html_e('Account ID', 'app-for-delivery-drivers'); ?>:
										 <?php echo esc_html($account_id); ?></p>
									
									<?php endif; ?>
	
									<?php if (isset($account_status)) : ?>
									
										<p><?php esc_html_e('Status', 'app-for-delivery-drivers'); ?>:
										 <?php echo esc_html($account_status); ?></p>
									
									<?php endif; ?>
	
									<?php if (isset($web_panel_url)) : ?>
									
										<p><?php esc_html_e('Web Panel URL', 'app-for-delivery-drivers'); ?>:
										 <a href="<?php echo esc_url($web_panel_url); ?>" target="_blank"><?php echo esc_html($web_panel_url); ?></a></p>
									
									<?php endif; ?>
								 
							<?php } ?>
	
							
						</div>
					</div>

					<div class="postbox afdd-account-sync">
						<div class="inside"> 				
					<?php if ($account_token) : ?>
								<!-- Sync Account Form when account token exists -->
								<h2><?php esc_html_e('Sync Account', 'app-for-delivery-drivers'); ?></h2>
								<p><?php esc_html_e('Your account is currently synchronized. To ensure all your drivers and settings are up-to-date, click the button below to manually sync data to the app.', 'app-for-delivery-drivers'); ?></p>
								
								<form method="post" action="<?php echo esc_url(admin_url('admin-post.php')); ?>">
									<?php wp_nonce_field('afdd_sync_account_nonce', 'afdd_sync_account_nonce_field'); ?>
									<input type="hidden" name="action" value="afdd_sync_account">
									<p><button type="submit" class="button button-primary"><?php esc_html_e('Sync Account Now', 'app-for-delivery-drivers'); ?></button></p>
								</form>
							<?php else : ?>
								<!-- Activation Prompt when no account token is found -->
								<h2><?php esc_html_e('Set Up App Account', 'app-for-delivery-drivers'); ?></h2>
								<p><?php esc_html_e('No account found. Click the button below to set up your account and activate your drivers and settings for the app.', 'app-for-delivery-drivers'); ?></p>
								<form method="post" action="<?php echo esc_url(admin_url('admin-post.php')); ?>">
									<?php wp_nonce_field('afdd_sync_account_nonce', 'afdd_sync_account_nonce_field'); ?>
									<input type="hidden" name="action" value="afdd_sync_account">
									<p><button type="submit" class="button button-primary"><?php esc_html_e('Set Up App Account', 'app-for-delivery-drivers'); ?></button></p>
								</form>
							<?php endif; ?>
					 </div>
					 </div>
	
					<!-- Get the Apps -->
					<div class="postbox afdd-apps-card">
					<div class="inside">
					<h2  ><?php esc_html_e('Get the App', 'app-for-delivery-drivers'); ?></h2>
						 
							<p><?php esc_html_e('Your drivers can download the app from the following stores:', 'app-for-delivery-drivers'); ?></p>
							<p>
								<a style="display: inline-block;margin-right: 10px;" href="https://play.google.com/store/apps/details?id=com.delivery.drivers" target="_blank">
									<img src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'assets/google-play-badge.png'); ?>" alt="<?php esc_attr_e('Get it on Google Play', 'app-for-delivery-drivers'); ?>" style = "height:50px;" >
								</a>
								<a style="display: inline-block;" href="https://apps.apple.com/app/delivery-drivers-app/id6739819854" target="_blank">
									<img src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'assets/app-store-badge.png'); ?>" alt="<?php esc_attr_e('Download on the App Store', 'app-for-delivery-drivers'); ?>" style = "height:50px;" >
								</a>
							</p>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}
	 
	

	/**
	 * Handle the sync account action.
	 *
	 * @since 1.0.0
	 */ 
	public function sync_account() {
	 
	    // Check nonce for security.
		if (!isset($_POST['afdd_sync_account_nonce_field']) || !wp_verify_nonce($_POST['afdd_sync_account_nonce_field'], 'afdd_sync_account_nonce')) {
			set_transient('afdd_api_error_message', __('Invalid request. Please refresh the page and try again.', 'app-for-delivery-drivers'), 30);
			wp_redirect(admin_url('admin.php?page=lddfw-app'));
			return;
		}
		 
		// Retrieve account ID and token.
		$account_id     = get_option('afdd_app_account_id');  
		$account_token  = get_option('afdd_app_token');  
		$site_data      = afdd_fs()->get_site();  
		  
		// Get web panel URL.
		$web_panel_url = lddfw_drivers_page_url('');

	    // Retrieve the owner email.
		$owner_email = get_option('woocommerce_email_from_address');
		if (empty($owner_email) || !is_email($owner_email)) {
			$owner_email = get_option('admin_email');
		}

		// Retrieve additional store information.
		$from_name    = get_option('woocommerce_email_from_name');
		$from_address = get_option('woocommerce_email_from_address');
		if (empty($from_address) || !is_email($from_address)) {
			$from_address = $owner_email;
		}
		 
		$admin_email = get_option('admin_email');

		$store_name        = get_option('blogname');
		$store_address     = get_option('woocommerce_store_address');
		$store_address_2   = get_option('woocommerce_store_address_2');
		$store_city        = get_option('woocommerce_store_city');
		$store_postcode    = get_option('woocommerce_store_postcode');
		$store_country_raw = get_option('woocommerce_default_country');
		 
		 // Split country and state codes.
		 if (strpos($store_country_raw, ':') !== false) {
			list($store_country_code, $store_state_code) = explode(':', $store_country_raw);
		} else {
			$store_country_code = $store_country_raw;
			$store_state_code   = '';
		}

		 // Initialize the WC_Countries class.
		 if (class_exists('WC_Countries')) {
			$woocommerce_countries = new WC_Countries();
			
			// Get the full country name.
			$store_country = isset($woocommerce_countries->countries[ $store_country_code ]) ? $woocommerce_countries->countries[ $store_country_code ] : $store_country_code;
			
			// Get the full state name (if available)
			if (!empty($store_state_code) && isset($woocommerce_countries->states[ $store_country_code ][ $store_state_code ])) {
				$store_state = $woocommerce_countries->states[ $store_country_code ][ $store_state_code ];
			} else {
				$store_state = $store_state_code;
			}
		} else {
			// Fallback if WC_Countries is not available.
			$store_country = $store_country_code;
			$store_state   = $store_state_code;
		}
		
		// Sanitize the retrieved values.
		$store_country = sanitize_text_field($store_country);
		$store_state   = sanitize_text_field($store_state);
 
		 // Get the list of drivers' emails.
		 $drivers = LDDFW_Driver::lddfw_get_drivers();
		 $driver_emails = array();
		 foreach ($drivers as $driver) {
			 $driver_id = $driver->ID;
			 $lddfw_driver_account = get_user_meta($driver_id, 'lddfw_driver_account', true);
			 if ('1' === $lddfw_driver_account) {
				 $driver_emails[] = $driver->user_email;
			 }
		 }
 
		 // Prepare data for API request.
		 $data = array(
			'site_info' => array(
				'site_id' => $site_data->site_id,
				'plugin_id' => $site_data->plugin_id,
				'user_id' => $site_data->user_id,
				'title' => $site_data->title,
				'url' => $site_data->url,
				'version' => $site_data->version,
				'language' => $site_data->language,
				'plan_id' => $site_data->plan_id,
				'license_id' => $site_data->license_id,
				'trial_plan_id' => $site_data->trial_plan_id,
				'trial_ends' => $site_data->trial_ends,
				'is_premium' => $site_data->is_premium,
				'is_disconnected' => $site_data->is_disconnected,
				'is_active' => $site_data->is_active,
				'is_uninstalled' => $site_data->is_uninstalled,
				'is_beta' => $site_data->is_beta,
				'public_key' => $site_data->public_key,
				'secret_key' => $site_data->secret_key,
				'id' => $site_data->id,
				'updated' => $site_data->updated,
				'created' => $site_data->created,
 
				'from_name'       => $from_name,
				'from_address'    => $from_address,
				'admin_email'     => $admin_email,
				'store_name'      => $store_name,
				'store_address'   => $store_address,
				'store_address_2' => $store_address_2,
				'store_city'      => $store_city,
				'store_state'     => $store_state,
				'store_country'   => $store_country,
				'store_postcode'  => $store_postcode,

			),
			'drivers' => $driver_emails,
			'drivers_web_panel' => $web_panel_url
		);

		  // Set headers, with Authorization if token exists
		  $headers = array(
			'Content-Type' => 'application/json'
		);
		if ($account_token) {
			$headers['Authorization'] = 'Bearer ' . $account_token;
		}
		 // Make the POST request to the API
		 $response = wp_remote_post('https://api.powerfulwp.com/api/user/sync-website-account', array(
			'method'    => 'POST',
			'body'      => json_encode($data),
			'headers'   => $headers,
		));
    
		// Handle API response
		if (is_wp_error($response)) {
			set_transient('afdd_api_error_message', __('Error connecting to the API.', 'app-for-delivery-drivers'), 30);
			wp_redirect(admin_url('admin.php?page=lddfw-app'));
			return;
		}

		 // Get the HTTP status code
		 $http_status = wp_remote_retrieve_response_code($response);

		 $response_body = wp_remote_retrieve_body($response);
		 $result = json_decode($response_body);
	 
		 // Check if there's a 'status' field in the response
		 if (isset($result->status) && $result->status == 'error') {
			 // Print the message from the response
			 $error_message = isset($result->message) ? $result->message : 'Unknown error occurred.';
			 set_transient('afdd_api_error_message', sprintf(__('Error: %s', 'app-for-delivery-drivers'), $error_message), 30);
			 wp_redirect(admin_url('admin.php?page=lddfw-app'));
			 return;
		 }

		  // If HTTP status is not 200 and no error was explicitly returned
		  if ($http_status != 200) {
			set_transient('afdd_api_error_message', __('An unknown error occurred.', 'app-for-delivery-drivers'), 30);
			wp_redirect(admin_url('admin.php?page=lddfw-app'));
			return;
		}

		// Handle successful response.
		if (isset($result->id) && isset($result->token)) {
 			// Store account ID and token in WordPress options
			update_option('afdd_app_account_id', sanitize_text_field($result->id));
			update_option('afdd_app_token', sanitize_text_field($result->token));
			set_transient('afdd_api_success_message', __('Account successfully synced.', 'app-for-delivery-drivers'), 30);
		} else {
			set_transient('afdd_api_error_message', __('Failed to sync account.', 'app-for-delivery-drivers'), 30);
		}
	
		wp_redirect(admin_url('admin.php?page=lddfw-app'));
		return;
  
	}
 
	/**
	 * Display admin notices for success or error messages.
	 *
	 * @since 1.0.0
	 */
	public function admin_notices() {
		// Check if an error message exists.
		if ( $message = get_transient('afdd_api_error_message') ) {
			?>
			<div class="notice notice-error is-dismissible">
				<p><?php echo esc_html( $message ); ?></p>
			</div>
			<?php
			// Delete the transient so it doesn't persist.
			delete_transient('afdd_api_error_message');
		}
	
		// Check if a success message exists.
		if ( $message = get_transient('afdd_api_success_message') ) {
			?>
			<div class="notice notice-success is-dismissible">
				<p><?php echo esc_html( $message ); ?></p>
			</div>
			<?php
			// Delete the transient so it doesn't persist.
			delete_transient('afdd_api_success_message');
		}
	}
	
	/**
	 * Send notification when a driver is assigned to an order by the store.
	 *
	 * @since 1.0.0
	 *
	 * @param int           $order_id   The order ID.
	 * @param WC_Order|bool $order      The order object.
	 * @param string        $operator   Who assigned the driver ('store' or 'driver').
	 * @param int           $driver_id  The driver ID.
	 */
	public function send_notification($order_id, $order = false,  $operator, $driver_id ) {

		// Send notification only when the store or auto-assign process assigned the order to the driver.
		// Skip sending notification if the driver self-assigned the order.
		if ( 'store' !== $operator ) {
			return;
		}

		if ($order_id && !is_a($order, 'WC_Order')) {
			$order = wc_get_order($order_id);
		}
	
		if (is_a($order, 'WC_Order')) {
			// Retrieve account ID and token.
			$account_id    = get_option('afdd_app_account_id');  
			$account_token = get_option('afdd_app_token');  
	
			$driver_id = $order->get_meta('lddfw_driverid');
			$user_info = get_userdata($driver_id);
	
			$email        = $user_info->user_email;
			$order_number = $order->get_order_number();
			$locale       = get_locale(); // Fetch the locale
	
			if ($account_token) {
				// Prepare the API request to send assigned order notification.
				$response = wp_remote_post('https://api.powerfulwp.com/api/user/send-assigned-order-notification', array(
					'method'    => 'POST',
					'body'      => json_encode(array(
						'site_id'      => $account_id,
						'order_number' => $order_number,
						'locale'       => $locale,
						'email'        => $email
					)),
					'headers'   => array(
						'Content-Type'  => 'application/json',
						'Authorization' => 'Bearer ' . $account_token
					),
				));
	
				// Get the response body and decode it into an associative array
				$response_body = wp_remote_retrieve_body($response);
				$website_data  = json_decode($response_body, true);
				 
				if (is_wp_error($response)) {
					// If there's a WP error, add an order note with the error message
					$order->add_order_note('Push Notification: API call failed.');
				} elseif (isset($website_data['status'])) {
					// Check if the API returned a status in the response
					if ($website_data['status'] === 1) {
						// On success, add an order note with relevant data
						$order->add_order_note("Push Notification: Notification sent successfully");
					} elseif ($website_data['status'] === 0) {
						// On error, add an order note with the error message from the API
						$order->add_order_note("Push Notification: Notification failed. API error: " . $website_data['message']);
					} else {
						// Handle unexpected status or missing status in the API response
						$order->add_order_note('Push Notification: Unexpected response from API.' );
					}
				} else {
					// If there's no status or the response is malformed
					$order->add_order_note('Push Notification: Invalid response received from API.' );
				}
			} else {
				// Add an order note if no account token is available
				$order->add_order_note('Push Notification: No account token provided. Notification could not be sent.');
			}
		}
	}
	
	/**
	 * Handle the Send App Invitation action from the settings page.
	 *
	 * @since 1.0.0
	 */
	function afdd_handle_send_invitation_action() {
		// Check if the current user has the required capability
		if (!current_user_can('manage_options')) {
			wp_die(__('You are not allowed to perform this action.', 'app-for-delivery-drivers'));
		}

		// Verify the nonce for security
		if (!isset($_POST['afdd_send_invitation_nonce_field']) || !wp_verify_nonce($_POST['afdd_send_invitation_nonce_field'], 'afdd_send_invitation_nonce')) {
			wp_die(__('Nonce verification failed.', 'app-for-delivery-drivers'));
		}

		// Sanitize and retrieve the driver email
		$driver_email = isset($_POST['driver_email']) ? sanitize_email($_POST['driver_email']) : '';

		// Check if the driver email is valid
		if (empty($driver_email) || !is_email($driver_email)) {
			

			set_transient('afdd_api_error_message', esc_html__('Invalid driver email address.', 'app-for-delivery-drivers') , 30);

			wp_redirect(add_query_arg(array('page' => 'lddfw-app'), admin_url('admin.php')));
			exit;
		}

		// Call the function to send the invitation
		$result = $this->afdd_send_driver_invitation($driver_email);
	
		// Add the result message to be displayed on the settings page
		if ($result['status'] === 'success') {
			set_transient('afdd_api_success_message',esc_html($result['message']), 30);
		} else {
			set_transient('afdd_api_error_message',esc_html($result['message']), 30);
		}

		// Redirect back to the settings page
		wp_redirect(add_query_arg(array('page' => 'lddfw-app'), admin_url('admin.php')));
		exit;
	}

	/**
	 * Sends an app invitation to a driver.
	 *
	 * @since 1.0.0
	 *
	 * @param string $driver_email The email address of the driver to invite.
	 * @return array An array containing the status and message.
	 */
	function afdd_send_driver_invitation($driver_email) {
	 
    // Sanitize the driver's email address
    $driver_email = sanitize_email($driver_email);

    if (empty($driver_email) || !is_email($driver_email)) {
        return array(
            'status'  => 'error',
            'message' => __('Invalid driver email address.', 'app-for-delivery-drivers'),
        );
    }

    // Retrieve the account ID and token from WordPress options
    $account_id    = get_option('afdd_app_account_id');
    $account_token = get_option('afdd_app_token');

    if (empty($account_id) || empty($account_token)) {
        return array(
            'status'  => 'error',
            'message' => __('Account ID or token is missing. Please reconnect the plugin.', 'app-for-delivery-drivers'),
        );
    }

    // Prepare the API endpoint URL
    $api_url = 'https://api.powerfulwp.com/api/user/send-invitation-to-driver'; // Replace with your actual API endpoint

    // Prepare the data payload
    $body = array(
        'account_id'   => $account_id,
        'driver_email' => $driver_email,
    );
 
    // Set up the headers, including the authorization token
    $headers = array(
        'Content-Type'  => 'application/json',
        'Authorization' => 'Bearer ' . $account_token,
    );

    // Make the POST request to the API endpoint
    $response = wp_remote_post($api_url, array(
        'headers' => $headers,
        'body'    => json_encode($body),
        'timeout' => 30,
    ));
 
    // Check for errors in the request
    if (is_wp_error($response)) {
        return array(
            'status'  => 'error',
            'message' => __('Failed to send invitation. Error: ', 'app-for-delivery-drivers') . $response->get_error_message(),
        );
    }
	 
    // Decode the API response
    $response_body = wp_remote_retrieve_body($response);
    $api_response  = json_decode($response_body, true);

    // Handle the API response
    if (isset($api_response['status']) && $api_response['status'] === 'success') {
        return array(
            'status'  => 'success',
            'message' => sprintf(__('Invitation sent successfully to %s.', 'app-for-delivery-drivers'), $driver_email),
        );
    } else {
        // Extract error message from API response
        $error_message = isset($api_response['message']) ? $api_response['message'] : __('Unknown error.', 'app-for-delivery-drivers');
        return array(
            'status'  => 'error',
            'message' => __('Failed to send invitation. Error: ', 'app-for-delivery-drivers') . $error_message,
        );
    }
}

}
