<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://https://powerfulwp.com/
 * @since             1.0.0
 * @package           App_For_Delivery_Drivers
 *
 * @wordpress-plugin
 * Plugin Name:       App for Delivery Drivers
 * Plugin URI:        https://https://powerfulwp.com/app-for-delivery-drivers
 * Description:       This addon enables your delivery drivers to use a dedicated app that displays the delivery driver panel via WebView, providing seamless integration with the Local Delivery Drivers for WooCommerce plugin. It enhances functionality with real-time tracking, push notifications, and allows drivers to manage and track their deliveries directly through the app. This ensures a smoother, more efficient delivery process for both drivers and store owners.
 * Version:           1.0.0
 * Update URI: https://api.freemius.com
 * Author:            powerfulwp
 * Author URI:        https://https://powerfulwp.com//
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       app-for-delivery-drivers
 * Domain Path:       /languages
 */
// If this file is called directly, abort.
if ( !defined( 'WPINC' ) ) {
    die;
}
/**
 * Declare compatibility with HPOS (High-Performance Order Storage).
 */
add_action( 'before_woocommerce_init', function () {
    if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
        \Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
    }
} );
if ( !function_exists( 'afdd_fs' ) ) {
    function afdd_fs() {
        global $afdd_fs;
        if ( !isset( $afdd_fs ) ) {
            // Include Freemius SDK.
            if ( file_exists( dirname( dirname( __FILE__ ) ) . '/local-delivery-drivers-for-woocommerce/freemius/start.php' ) ) {
                // Try to load SDK from parent plugin folder.
                require_once dirname( dirname( __FILE__ ) ) . '/local-delivery-drivers-for-woocommerce/freemius/start.php';
            } else {
                if ( file_exists( dirname( dirname( __FILE__ ) ) . '/local-delivery-drivers-for-woocommerce-premium/freemius/start.php' ) ) {
                    // Try to load SDK from premium parent plugin folder.
                    require_once dirname( dirname( __FILE__ ) ) . '/local-delivery-drivers-for-woocommerce-premium/freemius/start.php';
                } else {
                    require_once dirname( __FILE__ ) . '/freemius/start.php';
                }
            }
            $afdd_fs = fs_dynamic_init( array(
                'id'               => '16681',
                'slug'             => 'app-for-delivery-drivers',
                'type'             => 'plugin',
                'public_key'       => 'pk_6f21589a20077c0831c7e4e9e25d4',
                'is_premium'       => true,
                'is_premium_only'  => true,
                'has_paid_plans'   => true,
                'is_org_compliant' => false,
                'trial'            => array(
                    'days'               => 7,
                    'is_require_payment' => true,
                ),
                'parent'           => array(
                    'id'         => '6995',
                    'slug'       => 'local-delivery-drivers-for-woocommerce',
                    'public_key' => 'pk_5ae065da4addc985fe67f63c46a51',
                    'name'       => 'Local Delivery Drivers for WooCommerce',
                ),
                'menu'             => array(
                    'slug'       => 'app-for-delivery-drivers',
                    'first-path' => 'admin.php?page=afdd-settings',
                    'support'    => false,
                    'parent'     => array(
                        'slug' => 'lddfw-dashboard',
                    ),
                ),
                'is_live'          => true,
            ) );
        }
        return $afdd_fs;
    }

    /**
     * Currently plugin version.
     * Start at version 1.0.0 and use SemVer - https://semver.org
     * Rename this for your plugin and update it as you release new versions.
     */
    define( 'App_For_Delivery_Drivers_VERSION', '1.0.0' );
    /**
     * The code that runs during plugin activation.
     * This action is documented in includes/class-app-for-delivery-drivers-activator.php
     */
    function activate_App_For_Delivery_Drivers() {
        require_once plugin_dir_path( __FILE__ ) . 'includes/class-app-for-delivery-drivers-activator.php';
        App_For_Delivery_Drivers_Activator::activate();
    }

    /**
     * The code that runs during plugin deactivation.
     * This action is documented in includes/class-app-for-delivery-drivers-deactivator.php
     */
    function deactivate_App_For_Delivery_Drivers() {
        require_once plugin_dir_path( __FILE__ ) . 'includes/class-app-for-delivery-drivers-deactivator.php';
        App_For_Delivery_Drivers_Deactivator::deactivate();
    }

    register_activation_hook( __FILE__, 'activate_App_For_Delivery_Drivers' );
    register_deactivation_hook( __FILE__, 'deactivate_App_For_Delivery_Drivers' );
    /**
     * The core plugin class that is used to define internationalization,
     * admin-specific hooks, and public-facing site hooks.
     */
    require plugin_dir_path( __FILE__ ) . 'includes/class-app-for-delivery-drivers.php';
    /**
     * Begins execution of the plugin.
     *
     * Since everything within the plugin is registered via hooks,
     * then kicking off the plugin from this point in the file does
     * not affect the page life cycle.
     *
     * @since    1.0.0
     */
    function run_App_For_Delivery_Drivers() {
        $plugin = new App_For_Delivery_Drivers();
        $plugin->run();
    }

    function afdd_fs_is_parent_active_and_loaded() {
        // Check if the parent's init SDK method exists.
        return function_exists( 'lddfw_fs' );
    }

    function afdd_fs_is_parent_active() {
        $active_plugins = get_option( 'active_plugins', array() );
        if ( is_multisite() ) {
            $network_active_plugins = get_site_option( 'active_sitewide_plugins', array() );
            $active_plugins = array_merge( $active_plugins, array_keys( $network_active_plugins ) );
        }
        foreach ( $active_plugins as $basename ) {
            if ( 0 === strpos( $basename, 'local-delivery-drivers-for-woocommerce-premium/' ) ) {
                return true;
            }
        }
        return false;
    }

    function afdd_fs_init() {
        if ( afdd_fs_is_parent_active_and_loaded() ) {
            // Init Freemius.
            afdd_fs();
            // Signal that the add-on's SDK was initiated.
            do_action( 'afdd_fs_loaded' );
            // Parent is active, add your init code here.
            run_App_For_Delivery_Drivers();
        } else {
            // Parent is inactive, add your error handling here.
        }
    }

    // Include the internationalization class to handle text domain loading.
    require_once plugin_dir_path( __FILE__ ) . 'includes/class-app-for-delivery-drivers-i18n.php';
    /**
     * Initializes internationalization (i18n) support for the plugin.
     */
    function afdd_initialize_i18n() {
        // Create an instance of the Payments_For_Delivery_Drivers_i18n class.
        $plugin_i18n = new App_For_Delivery_Drivers_i18n();
        add_action( 'plugins_loaded', array($plugin_i18n, 'load_plugin_textdomain') );
    }

    // Call the function to initialize internationalization support.
    afdd_initialize_i18n();
    /**
     * Admin notices function.
     *
     * @since 1.0.0
     */
    function afdd_admin_notices() {
        if ( !class_exists( 'WooCommerce' ) ) {
            echo '<div class="notice notice-error is-dismissible">
					<p>' . esc_html( __( 'App for Delivery Drivers is a WooCommerce add-on, you must activate a WooCommerce on your site.', 'app-for-delivery-drivers' ) ) . '</p>
					</div>';
        }
    }

    /**
     * Show an admin notice if Local Delivery Drivers version is incorrect.
     */
    function afdd_version_error_notice() {
        echo '<div class="notice notice-error is-dismissible">
        <p>' . esc_html__( 'App for Delivery Drivers requires version 1.9.6 or higher of Local Delivery Drivers for WooCommerce Premium plugin. Please update the Local Delivery Drivers plugin to continue using this plugin.', 'app-for-delivery-drivers' ) . '</p>
    </div>';
    }

    /**
     * Initialize plugin on `plugins_loaded`.
     */
    function initialize_afdd_run() {
        if ( !class_exists( 'WooCommerce' ) ) {
            // Adding action to admin_notices to display a notice if WooCommerce is not active.
            add_action( 'admin_notices', 'afdd_admin_notices' );
            return;
            // Stop the initialization as WooCommerce is not active.
        }
        if ( defined( 'LDDFW_VERSION' ) ) {
            $required_version = '1.9.5';
            $current_version = LDDFW_VERSION;
            // If the version is lower than the required version, deactivate the plugin and show a notice.
            if ( version_compare( $current_version, $required_version, '<' ) ) {
                // Display an admin notice.
                add_action( 'admin_notices', 'afdd_version_error_notice' );
                return;
            }
        }
        if ( afdd_fs_is_parent_active_and_loaded() ) {
            // If parent already included, init add-on.
            afdd_fs_init();
        } else {
            if ( afdd_fs_is_parent_active() ) {
                // Init add-on only after the parent is loaded.
                add_action( 'lddfw_fs_loaded', 'afdd_fs_init' );
            } else {
                // Even though the parent is not activated, execute add-on for activation / uninstall hooks.
                afdd_fs_init();
            }
        }
    }

    add_action( 'plugins_loaded', 'initialize_afdd_run', 21 );
}