<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://powerfulwp.com/
 * @since      1.0.0
 *
 * @package    Distance_Rate_Shipping_For_Woocommerce_Powerfulwp
 * @subpackage Distance_Rate_Shipping_For_Woocommerce_Powerfulwp/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Distance_Rate_Shipping_For_Woocommerce_Powerfulwp
 * @subpackage Distance_Rate_Shipping_For_Woocommerce_Powerfulwp/admin
 * @author     PowerfulWP <apowerfulwp@gmail.com>
 */
class Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/distance-rate-shipping-for-woocommerce-powerfulwp-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/distance-rate-shipping-for-woocommerce-powerfulwp-admin.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Distance rate shipping method file.
	 *
	 * @return void
	 */
	public function distance_rate_shipping_method() {
		 include plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-distance-rate-shipping-for-woocommerce-powerfulwp-shipping-method.php';
	}

	/**
	 * Add distance rate shipping method.
	 *
	 * @param array $methods methods.
	 * @return array
	 */
	public function add_distance_rate_shipping_method( $methods ) {
		$methods['drsfwwp_distance_rate'] = 'Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Shipping_Method';
		return $methods;
	}

}
