<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://powerfulwp.com/
 * @since             1.0.0
 * @package           Distance_Rate_Shipping_For_Woocommerce_Powerfulwp
 *
 * @wordpress-plugin
 * Plugin Name: Distance Rate Shipping for WooCommerce - PowerfulWP Premium
 * Plugin URI:        https://powerfulwp.com/distance-rate-shipping-for-woocommerce
 * Description:       This is a short description of what the plugin does. It's displayed in the WordPress admin area.
 * Version:           1.0.5

 * Update URI: https://api.freemius.com
 * Author:            PowerfulWP
 * Author URI:        https://powerfulwp.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       distance-rate-shipping-for-woocommerce-powerfulwp
 * Domain Path:       /languages
 */
// If this file is called directly, abort.
if ( !defined( 'WPINC' ) ) {
    die;
}
// Declare extension compatible with HPOS.
add_action( 'before_woocommerce_init', function () {
    if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
        \Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
    }
} );
if ( !function_exists( 'drsfwp_fs' ) ) {
    // Create a helper function for easy SDK access.
    function drsfwp_fs() {
        global $drsfwp_fs;
        if ( !isset( $drsfwp_fs ) ) {
            // Activate multisite network integration.
            if ( !defined( 'WP_FS__PRODUCT_10993_MULTISITE' ) ) {
                define( 'WP_FS__PRODUCT_10993_MULTISITE', true );
            }
            // Include Freemius SDK.
            require_once dirname( __FILE__ ) . '/freemius/start.php';
            $drsfwp_fs = fs_dynamic_init( array(
                'id'             => '10993',
                'slug'           => 'distance-rate-shipping-for-woocommerce-powerfulwp',
                'type'           => 'plugin',
                'public_key'     => 'pk_be27124a087bf9bb0a6d84753542b',
                'is_premium'     => true,
                'premium_suffix' => 'Premium',
                'has_addons'     => false,
                'has_paid_plans' => true,
                'trial'          => array(
                    'days'               => 14,
                    'is_require_payment' => false,
                ),
                'menu'           => array(
                    'first-path' => 'plugins.php',
                    'support'    => false,
                ),
                'is_live'        => true,
            ) );
        }
        return $drsfwp_fs;
    }

    // Init Freemius.
    drsfwp_fs();
    // Signal that SDK was initiated.
    do_action( 'drsfwp_fs_loaded' );
}
/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'DISTANCE_RATE_SHIPPING_FOR_WOOCOMMERCE_POWERFULWP_VERSION', '1.0.5' );
/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-distance-rate-shipping-for-woocommerce-powerfulwp-activator.php
 */
function activate_distance_rate_shipping_for_woocommerce_powerfulwp() {
    require_once plugin_dir_path( __FILE__ ) . 'includes/class-distance-rate-shipping-for-woocommerce-powerfulwp-activator.php';
    Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-distance-rate-shipping-for-woocommerce-powerfulwp-deactivator.php
 */
function deactivate_distance_rate_shipping_for_woocommerce_powerfulwp() {
    require_once plugin_dir_path( __FILE__ ) . 'includes/class-distance-rate-shipping-for-woocommerce-powerfulwp-deactivator.php';
    Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_distance_rate_shipping_for_woocommerce_powerfulwp' );
register_deactivation_hook( __FILE__, 'deactivate_distance_rate_shipping_for_woocommerce_powerfulwp' );
/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-distance-rate-shipping-for-woocommerce-powerfulwp.php';
/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_distance_rate_shipping_for_woocommerce_powerfulwp() {
    $plugin = new Distance_Rate_Shipping_For_Woocommerce_Powerfulwp();
    $plugin->run();
}

/**
 * Admin notices function.
 *
 * @since 1.0.0
 */
function drsfwwp_admin_notices() {
    if ( !class_exists( 'WooCommerce' ) ) {
        echo '<div class="notice notice-error is-dismissible">
				<p>' . esc_html( __( 'Distance Rate Shipping for WooCommerce is a WooCommerce add-on, you must activate a WooCommerce on your site.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) ) . '</p>
				</div>';
    }
}

/**
 * Initializes the plugin.
 * This function checks if WooCommerce is active before running the plugin.
 * If WooCommerce is not active, it displays an admin notice.
 */
function initialize_drsfwwp_run() {
    // Check if WooCommerce is active.
    if ( !class_exists( 'WooCommerce' ) ) {
        // Adding action to admin_notices to display a notice if WooCommerce is not active.
        add_action( 'admin_notices', 'drsfwwp_admin_notices' );
        return;
        // Stop the initialization as WooCommerce is not active.
    }
    // WooCommerce is active, so initialize the plugin.
    run_distance_rate_shipping_for_woocommerce_powerfulwp();
}

// Include the internationalization class to handle text domain loading.
require_once plugin_dir_path( __FILE__ ) . 'includes/class-distance-rate-shipping-for-woocommerce-powerfulwp-i18n.php';
/**
 * Initializes internationalization (i18n) support for the plugin.
 */
if ( !function_exists( 'drsfwwp_initialize_i18n' ) ) {
    function drsfwwp_initialize_i18n() {
        // Create an instance of the drsfwwp_I18n class.
        $plugin_i18n = new Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_i18n();
        // Hook the 'load_plugin_textdomain' method of the Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_i18n class to the 'plugins_loaded' action.
        // This ensures that the plugin's text domain is loaded as soon as all plugins are loaded by WordPress,
        // making translations available.
        add_action( 'plugins_loaded', array($plugin_i18n, 'load_plugin_textdomain') );
    }

}
// Call the function to initialize internationalization support.
drsfwwp_initialize_i18n();
add_action( 'plugins_loaded', 'initialize_drsfwwp_run', 20 );