<?php
/**
 * Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Shipping_Method
 *
 * @package Distance_Rate_Shipping_For_Woocommerce_Powerfulwp
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Shipping_Method' ) ) {

	/**
	 * Distance rate shipping method.
	 *
	 * @package    Distance_Rate_Shipping_For_Woocommerce_Powerfulwp
	 * @subpackage Distance_Rate_Shipping_For_Woocommerce_Powerfulwp/includes
	 * @author     PowerfulWP <apowerfulwp@gmail.com>
	 */
	class Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Shipping_Method extends WC_Shipping_Method {

		/**
		 * Shipping cost.
		 *
		 * @var int
		 */
		protected $shipping_rate;

		/**
		 * Notice for customers.
		 *
		 * @var string
		 */
		public $notice = '';

		/**
		 * Add notice for customers.
		 *
		 * @param string $notice_text notice text.
		 * @return void
		 */
		public function set_notice( $notice_text = '' ) {
			$this->notice = $notice_text;
			add_filter( 'woocommerce_no_shipping_available_html', array( $this, 'show_notice' ) );
			add_filter( 'woocommerce_cart_no_shipping_available_html', array( $this, 'show_notice' ) );
		}

		/**
		 * Get the corrent notice.
		 *
		 * @return string
		 */
		public function show_notice() {
			return $this->notice;
		}

		/**
		 * Constructor.
		 *
		 * @param int $instance_id Instance ID.
		 */
		public function __construct( $instance_id = 0 ) {
			$this->id           = 'drsfwwp_distance_rate';
			$this->instance_id  = absint( $instance_id );
			$this->method_title = __( 'Distance Rate', 'distance-rate-shipping-for-woocommerce-powerfulwp' );
			$this->supports     = array(
				'shipping-zones',
				'instance-settings',
				'settings',
				'instance-settings-modal',
			);

			$this->enabled = isset( $this->settings['enabled'] ) ? $this->settings['enabled'] : 'yes';
			$this->title   = isset( $this->settings['title'] ) ? $this->settings['title'] : __( 'Distance Rate', 'drsfwwp' );

			$this->init();
		}

		/**
		 * Init function.
		 *
		 * @access private
		 * @return void
		 */
		public function init() {
			// Load the settings.
			$this->init_form_fields();
			$this->set_settings();
			add_action( 'woocommerce_update_options_shipping_' . $this->id, array( $this, 'process_admin_options' ) );
		}

		/**
		 * Initialize settings
		 *
		 * @return bool
		 */
		public function set_settings() {
			$this->title             = $this->get_option( 'title', $this->method_title );
			$this->cost              = $this->get_option( 'cost', '' );
			$this->pickup_address    = $this->get_option( 'pickup_address', '' );
			$this->google_key        = $this->get_option( 'google_key', '' );
			$this->travel_mode       = $this->get_option( 'travel_mode', '' );
			$this->unit_system       = $this->get_option( 'unit_system', '' );
			$this->distance_min      = $this->get_option( 'distance_min', '' );
			$this->distance_max      = $this->get_option( 'distance_max', '' );
			$this->distance_time_min = $this->get_option( 'distance_time_min', '' );
			$this->distance_time_max = $this->get_option( 'distance_time_max', '' );
			$this->weight_min        = $this->get_option( 'weight_min', '' );
			$this->weight_max        = $this->get_option( 'weight_max', '' );
			$this->quantity_min      = $this->get_option( 'quantity_min', '' );
			$this->quantity_max      = $this->get_option( 'quantity_max', '' );
			$this->quantity_multiply = $this->get_option( 'quantity_multiply', '' );
			$this->total_min         = $this->get_option( 'total_min', '' );
			$this->calculation_type  = $this->get_option( 'calculation_type', 'distance' );
			$this->travel_time_label = $this->get_option( 'travel_time_label', '' );
			$this->distance_label    = $this->get_option( 'distance_label', '' );
			$this->debug_mode        = $this->get_option( 'debug_mode', '' );
			return true;
		}


		/**
		 * Define shipping method fields.
		 */
		public function init_form_fields() {

			$this->form_fields = array(
				'google_key'        => array(
					'title'       => __( 'Google API Key', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'text',
					'description' => sprintf( __( 'Enter the Google Key for Distance Matrix API. ( Application restrictions: IP addresses ), for more information on how to create the Google key %1$sclick here%2$s', 'distance-rate-shipping-for-woocommerce-powerfulwp' ), '<a target="_blank" href="https://powerfulwp.com/docs/distance-rate-shipping-for-woocommerce/getting-started/how-to-generate-and-set-the-google-distance-matrix-api-key">', '</a>' ),
				),

				'travel_mode'       => array(
					'title'       => __( 'Transportation Mode', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'select',
					'default'     => 'DRIVING',
					'options'     => array(
						'DRIVING'   => __( 'Driving', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
						'BICYCLING' => __( 'Bicycling', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
						'WALKING'   => __( 'Walking', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					),
					'description' => __( 'Select a transportation mode to use for distance calculation.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),

				),
				'unit_system'       => array(
					'title'       => __( 'Distance unit system', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'select',
					'default'     => 'metric',
					'options'     => array(
						'imperial' => __( 'Miles', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
						'metric'   => __( 'Kilometres', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					),
					'description' => __( 'Select a unit system to use for distance calculation.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
				),

				'distance_label'    => array(
					'title'       => __( 'Show the distance', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'checkbox',
					'description' => __( 'Show the distance next to the shipping cost.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
				),

				'travel_time_label' => array(
					'title'       => __( 'Show the travel time', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'checkbox',
					'description' => __( 'Show the travel time next to the shipping cost.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
				),

				'debug_mode'        => array(
					'title'       => __( 'Debug', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'checkbox',
					'description' => __( 'Show debug notices on checkout.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
				),

			);

			$this->instance_form_fields = array(
				'title'             => array(
					'title'       => __( 'Shipping Method Title', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'text',
					'description' => __( 'This is the title of the shipping method on checkout.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'default'     => __( 'Distance Rate', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
				),

				'calculation_type'  => array(
					'title'   => __( 'Calculation Type', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'    => 'select',
					'default' => 'distance',
					'options' => array(
						'distance'      => __( 'Distance', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
						'distance_time' => __( 'Distance Time', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					),
				),

				'cost'              => array(
					'title'       => __( 'Cost', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'description' => __( 'Enter the cost per unit. If your calculation type is by distance, enter the price for one mile/km. By distance time, enter the cost for one minute.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'text',
				),

				'tax_status'        => array(
					'title'   => __( 'Tax Status', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'    => 'select',
					'default' => 'taxable',
					'options' => array(
						'taxable' => __( 'Taxable', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
						'none'    => _x( 'None', 'Tax status', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					),
				),

				'pickup_address'    => array(
					'title'       => __( 'Pick Up Address', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'text',
					'description' => __( 'Enter the address that you ship from. ( address, city, zipcode, country ) , leave blank to ship from your store address', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
				),

				'distance_min'      => array(
					'title'       => __( 'Min Distance', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'description' => __( 'Enter the minimum distance limitation ( mile/km )', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'text',
				),

				'distance_max'      => array(
					'title'       => __( 'Max Distance', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'description' => __( 'Enter the maximum distance limitation ( mile/km )', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'text',
				),

				'distance_time_min' => array(
					'title'       => __( 'Min Distance Time', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'description' => __( 'Enter the minimum distance time limitation in minutes', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'text',
				),

				'distance_time_max' => array(
					'title'       => __( 'Max Distance Time', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'description' => __( 'Enter the maximum distance time limitation in minutes', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'text',
				),

				'weight_min'        => array(
					'title'       => __( 'Min Weight', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'description' => __( 'Enter the minimum cart weight limitation', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'text',
				),

				'weight_max'        => array(
					'title'       => __( 'Max Weight', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'description' => __( 'Enter the maximum cart weight limitation', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'text',
				),

				'total_min'         => array(
					'title'       => __( 'Min Total', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'description' => __( 'Enter the minimum cart total limitation', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'text',
				),

				'quantity_min'      => array(
					'title'       => __( 'Min Quantity', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'description' => __( 'Enter the minimum number of products limitation', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'text',
				),

				'quantity_max'      => array(
					'title'       => __( 'Max Quantity', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'description' => __( 'Enter the maximum number of products limitation', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'        => 'text',
				),

				'quantity_multiply' => array(
					'title' => __( 'Multiply by Quantity', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'label' => __( 'Multiply the shipping cost with the number of items in the cart', 'distance-rate-shipping-for-woocommerce-powerfulwp' ),
					'type'  => 'checkbox',
				),

			);
		}





		/**
		 * Calculate custom shipping method.
		 *
		 * @param array $package package.
		 *
		 * @return void
		 */
		public function calculate_shipping( $package = array() ) {
			if ( ! empty( $this->shipping_rate ) ) {
				$this->add_rate( $this->shipping_rate );
				do_action( 'woocommerce_' . $this->id . '_shipping_add_rate', $this, $this->shipping_rate );
			}
		}

		 /**
		  * Show debug notice.
		  *
		  * @param string $notice notice.
		  * @return void
		  */
		public function show_debug_notice( $notice ) {
			if ( 'yes' === $this->debug_mode ) {
				wc_add_notice( $notice, 'notice' );
			}
		}


		/**
		 * Calculate custom shipping method.
		 *
		 * @param array $package package.
		 *
		 * @return statement
		 */
		public function get_shipping_cost( $package = array() ) {

			// Check if address is exist.
			if ( empty( $package['destination']['address'] ) && isset( $_GET['wc-ajax'] ) && 'update_order_review' === $_GET['wc-ajax'] ) {
				 $this->show_debug_notice( __( 'Destination address is not exist', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
				 return false;
			}

			// Check cost price.
			if ( '' === $this->cost ) {
				$this->show_debug_notice( __( 'Shipping cost is empty', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
				return false;
			}

			// Get customer shipping address.
			$shipping_address = $this->get_shipping_address( $package );
			if ( false === $shipping_address ) {
				return false;
			}

			// Get pickup address.
			$pickup_address = $this->get_pickup_address( $package );
			if ( false === $pickup_address ) {
				return false;
			}

			// Get distance.
			$distance = $this->get_distance( $pickup_address, $shipping_address );
			if ( false === $distance ) {
				return false;
			}

			// Check shipping method limitation.
			$limitation = $this->check_limitation( $package, $distance );
			if ( false === $limitation ) {
				return false;
			}

			// Calculate distance cost.
			if ( 'distance' === $this->calculation_type ) {
				$cost = $this->get_distance_cost( $distance );
			}

			// Calculate distance time.
			if ( 'distance_time' === $this->calculation_type ) {
				$cost = $this->get_distance_time_cost( $distance );
			}

			$shipping_label = $this->title;
			$distance_label = $this->get_distance_label( $distance );
			if ( '' !== $distance_label ) {
				$shipping_label .= ' ' . $distance_label;
			}
			$rate = array(
				'id'      => $this->get_rate_id(),
				'label'   => $shipping_label,
				'cost'    => $cost,
				'package' => $package,
			);

			$this->shipping_rate = $rate;
			return true;
		}


		 /**
		  * Calculate Distance cost.
		  *
		  * @param array $distance distance array.
		  * @return string
		  */
		public function get_distance_cost( $distance ) {
			// Get distance value.
			$distance_value = floatval( $distance['distance_value'] );

			$cost_multiply = 1;

			// Cart quantity.
			$quantity = WC()->cart->get_cart_contents_count();
			if ( isset( $quantity ) && $quantity > 0 && 'yes' === $this->quantity_multiply ) {
				// Set quantity multiply value.
				$cost_multiply = $quantity;
			}

			// Calculate distance cost by unit system.
			if ( 'imperial' === $this->unit_system ) {
				return $distance_value / 1609 * $this->cost * $cost_multiply;
			} else {
				return $distance_value / 1000 * $this->cost * $cost_multiply;
			}

		}

		/**
		 * Distance label
		 *
		 * @param array $distance distance array.
		 * @return string
		 */
		public function get_distance_label( $distance ) {

			if ( '' === $this->travel_time_label && '' === $this->distance_label ) {
				return '';
			}

			$label = '( ';

			if ( 'yes' === $this->travel_time_label ) {
				$label .= $distance['duration_text'] . ', ';
			}

			if ( 'yes' === $this->distance_label ) {
				$label .= $distance['distance_text'] . ', ';
			}

			$label = substr( $label, 0, -2 );

			$label .= ' )';

			return $label;

		}
		/**
		 * Distance cost by travel time.
		 *
		 * @param array $distance distance array.
		 * @return string
		 */
		public function get_distance_time_cost( $distance ) {
			// Get distance value.
			$duration_value = floatval( $distance['duration_value'] );

			// Set quantity multiply value.
			$quantity_multiply = ! empty( $this->quantity_multiply ) ? (int) $this->quantity_multiply : 1;
			$quantity_multiply = $quantity_multiply < 1 ? 1 : $quantity_multiply;

			// Calculate distance cost by unit system.
			return $duration_value / 60 * $this->cost * $quantity_multiply;

		}




		/**
		 * Process setting options on save.
		 *
		 * @return void
		 */
		public function process_admin_options() {
			parent::process_admin_options();
			$this->init_settings();
			$this->delete_transients();
		}

		/**
		 * Check if shipping method is available.
		 *
		 * @param object $package package.
		 * @return boolean
		 */
		public function is_available( $package ) {

			if ( empty( $package['destination']['country'] ) ) {
				return false;
			}

			if ( ! $this->get_shipping_cost( $package ) ) {
				return false;
			}

			return apply_filters( 'woocommerce_shipping_' . $this->id . '_is_available', true, $package );
		}

		/**
		 * Delete transients.
		 *
		 * @return void
		 */
		public function delete_transients() {
			global $wpdb;
			$wpdb->query( "DELETE FROM `$wpdb->options` WHERE `option_name` LIKE ('_transient_drsfwp_%') OR `option_name` LIKE ('_transient_timeout_drsfwp_%')" );
		}


		/**
		 * Get the pickup address.
		 *
		 * @param object $package package.
		 * @return string
		 */
		public function get_pickup_address( $package ) {
			$address = '';

			// Get pickup address from shipping method.
			if ( '' !== $this->pickup_address ) {
				$address = $this->pickup_address;
				$address = str_replace( '+', '%2B', $address );
				$address = str_replace( '  ', ' ', trim( $address ) );
				$address = str_replace( ' ', '+', $address );
			} else {

				// Get the pickup address from the store address.
				$store_address = $this->store_address( 'map_address' );
				$address       = false === $store_address ? '' : $store_address;
			}

			$address = apply_filters( 'drsfwp_get_checkout_pickup_address', $address, $package, WC()->session->get( 'drsfwp_checkout_post_data' ) );

			if ( '' === $address ) {
				$this->show_debug_notice( __( 'Pickup address is not completed', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
				return false;
			}

			return $address;

		}


		/**
		 * Store address.
		 *
		 * @param string $format address format.
		 * @return string
		 */
		public function store_address( $format ) {

			// main store address.
			$store_address     = get_option( 'woocommerce_store_address', '' );
			$store_address_2   = get_option( 'woocommerce_store_address_2', '' );
			$store_city        = get_option( 'woocommerce_store_city', '' );
			$store_postcode    = get_option( 'woocommerce_store_postcode', '' );
			$store_raw_country = get_option( 'woocommerce_default_country', '' );

			if ( '' === $store_address && '' === $store_city ) {
				return false;
			}

			$split_country = explode( ':', $store_raw_country );
			if ( false === strpos( $store_raw_country, ':' ) ) {
				$store_country = $split_country[0];
				$store_state   = '';
			} else {
				$store_country = $split_country[0];
				$store_state   = $split_country[1];
			}
			if ( '' !== $store_country ) {
				$store_country = WC()->countries->countries[ $store_country ];
			}
			$array = array(
				'street_1' => $store_address,
				'street_2' => $store_address_2,
				'city'     => $store_city,
				'zip'      => $store_postcode,
				'country'  => $store_country,
				'state'    => $store_state,
			);
			return $this->format_address( $format, $array );
		}

		/**
		 * Format address.
		 *
		 * @since 1.0.0
		 * @param string $format address format.
		 * @param array  $array address array.
		 * @return string
		 */
		public function format_address( $format, $array ) {

			$address_1 = $array['street_1'];
			$address_2 = $array['street_2'];
			$city      = $array['city'];
			$postcode  = $array['zip'];
			$country   = $array['country'];
			$state     = $array['state'];

			if ( 'array' === $format ) {
				return $array;
			}

			if ( 'map_address' === $format ) {

				// Show state only for USA.
				if ( 'US' !== $array['country'] && 'United States (US)' !== $array['country'] ) {
					$state = '';
				}

				$address  = $address_1 . ', ';
				$address .= $city;
				if ( ! empty( $state ) || ! empty( $postcode ) ) {
					$address .= ', ';
				}
				if ( ! empty( $state ) ) {
					$address .= $state . ' ';
				}
				if ( ! empty( $postcode ) ) {
					$address .= $postcode . ' ';
				}
				if ( ! empty( $country ) ) {
					$address .= ' ' . $country;
				}
				$address = str_replace( '+', '%2B', $address );
				$address = str_replace( '  ', ' ', trim( $address ) );
				$address = str_replace( ' ', '+', $address );
				return $address;
			}

			if ( 'address_line' === $format ) {
				// Show state only for USA.
				if ( 'US' !== $array['country'] && 'United States (US)' !== $array['country'] ) {
					$state = '';
				}
				$address  = $address_1 . ', ';
				$address .= $city;
				if ( ! empty( $state ) || ! empty( $postcode ) ) {
					$address .= ', ';
				}
				if ( ! empty( $state ) ) {
					$address .= $state . ' ';
				}
				if ( ! empty( $postcode ) ) {
					$address .= $postcode . ' ';
				}
				if ( ! empty( $country ) ) {
					$address .= ' ' . $country;
				}
				$address = str_replace( '  ', ' ', trim( $address ) );
				return $address;
			}

			if ( 'address' === $format ) {
				// Format address.
				// Show state only for USA.
				if ( 'US' !== $array['country'] && 'United States (US)' !== $array['country'] ) {
					$state = '';
				}
				$address = '';
				if ( ! empty( $array['first_name'] ) ) {
					$first_name = $array['first_name'];
					$last_name  = $array['last_name'];
					$address    = $first_name . ' ' . $last_name . '<br>';
				}

				if ( ! empty( $array['company'] ) ) {
					$address .= $array['company'] . '<br>';
				}

				$address .= $address_1;

				if ( ! empty( $address_2 ) ) {
					$address .= ', ' . $address_2 . ' ';
				}
				$address .= '<br>' . $city;

				if ( ! empty( $state ) || ! empty( $postcode ) ) {
					$address .= ', ';
				}

				if ( ! empty( $state ) ) {
					$address .= $state . ' ';
				}
				if ( ! empty( $postcode ) ) {
					$address .= $postcode . ' ';
				}
				if ( ! empty( $country ) ) {
					$address .= '<br>' . $country;
				}
				return $address;
			}
		}

		/**
		 * Get customer shipping address.
		 *
		 * @param object $package package.
		 * @return string
		 */
		public function get_shipping_address( $package ) {
			$array = array();

			// Get address_1.
			if ( ! empty( $package['destination']['address'] ) ) {
				$array['address_1'] = $package['destination']['address'];
			} elseif ( ! empty( WC()->customer ) && ! empty( WC()->customer->get_shipping_address() ) ) {
				$array['address_1'] = WC()->customer->get_shipping_address();
			}

			// Get city.
			if ( ! empty( $package['destination']['city'] ) ) {
				$array['city'] = $package['destination']['city'];
			} elseif ( ! empty( WC()->customer ) && ! empty( WC()->customer->get_shipping_city() ) ) {
				$array['city'] = WC()->customer->get_shipping_city();
			}

			// Get state.
			if ( ! empty( $package['destination']['state'] ) ) {
				$state   = $package['destination']['state'];
				$country = $package['destination']['country'];

				// Get the full name of the state.
				if ( isset( WC()->countries->states[ $country ], WC()->countries->states[ $country ][ $state ] ) ) {
					$state   = WC()->countries->states[ $country ][ $state ];
					$country = WC()->countries->countries[ $country ];
				}
				$array['state'] = $state;
			}

			// Get postcode.
			if ( ! empty( $package['destination']['postcode'] ) ) {
				$array['postcode'] = $package['destination']['postcode'];
			}

			// Get country.
			if ( ! empty( $package['destination']['country'] ) ) {
				$country = $package['destination']['country'];

				// Get the full name of the country.
				if ( isset( WC()->countries->countries[ $country ] ) ) {
					$country = WC()->countries->countries[ $country ];
				}
				$array['country'] = $country;
			}

			// Return false is address is not completed.
			if ( empty( $array['country'] ) || empty( $array['city'] ) ) {
				$this->show_debug_notice( __( 'Shipping address is not completed', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
				return false;
			}

			// Format address.
			$address = '';
			if ( ! empty( $array['address_1'] ) ) {
				$address .= $array['address_1'] . ', ';
			}

			if ( ! empty( $array['city'] ) ) {
				$address .= $array['city'] . ', ';
			}

			if ( ! empty( $array['state'] ) ) {
				$address .= $array['state'] . ', ';
			}

			if ( ! empty( $array['postcode'] ) ) {
				$address .= $array['postcode'] . ', ';
			}

			if ( ! empty( $array['country'] ) ) {
				$address .= $array['country'];
			}

			$address = str_replace( '+', '%2B', $address );
			$address = str_replace( '  ', ' ', trim( $address ) );
			$address = str_replace( ' ', '+', $address );
			return $address;
		}





		/**
		 * Get distance.
		 *
		 * @since 1.0.0
		 * @param string $origin origin.
		 * @param string $destination destination.
		 * @return array
		 */
		public function get_distance( $origin, $destination ) {

			$this->show_debug_notice( 'Debug notice: origin = ' . $origin . ' ' . ' destination=' . $destination );

			$origin      = rawurlencode( $origin );
			$destination = rawurlencode( $destination );

			// Check all variables for distance matrix.
			if ( '' === $destination || '' === $origin || '' === $this->google_key || '' === $this->travel_mode || '' === $this->unit_system ) {
				$this->show_debug_notice( __( 'Distance matrix API is missing some params', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
				return false;
			}

			// Get distancematrix service.
			$url = 'https://maps.googleapis.com/maps/api/distancematrix/json?mode=' . $this->travel_mode . '&origins=' . $origin . '&destinations=' . $destination . '&key=' . $this->google_key . '&units=' . $this->unit_system . '&language=' . get_bloginfo( 'language' );

			// Set transient key.
			$transient = 'drsfwp_' . md5( $url );

			$set_cache = false;

			// Get distance from cache.
			$distancematrix = get_transient( $transient );
			if ( false === $distancematrix ) {

				// Get distance from google API.
				$response = wp_remote_get( $url );
				if ( is_wp_error( $response ) ) {
					$this->show_debug_notice( __( 'An unexpected error has occurred on Distance matrix API', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
					return false;
				}
				$distancematrix = wp_remote_retrieve_body( $response );

				$set_cache = true;

			}

			$obj = json_decode( $distancematrix );

			if ( empty( $obj->status ) ) {
				$this->show_debug_notice( __( 'An unexpected error has occurred on Distance matrix API', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
				return false;
			}

			if ( 'OK' !== $obj->status ) {
				$this->show_debug_notice( $obj->error_message );
				return false;
			}

			if ( 'OK' === $obj->status ) {
				$this->show_debug_notice( 'Debug notice: status ok' );
				// Get distance and duration.
				$distance_text  = ( ! empty( $obj->rows[0]->elements[0]->distance->text ) ) ? $obj->rows[0]->elements[0]->distance->text : '';
				$distance_value = ( ! empty( $obj->rows[0]->elements[0]->distance->value ) ) ? $obj->rows[0]->elements[0]->distance->value : '';
				$duration_value = ( ! empty( $obj->rows[0]->elements[0]->duration->value ) ) ? $obj->rows[0]->elements[0]->duration->value : '';
				$duration_text  = ( ! empty( $obj->rows[0]->elements[0]->duration->text ) ) ? $obj->rows[0]->elements[0]->duration->text : '';

				// Set order distance and duration.
				$distance_array = array(
					'distance_text'  => $distance_text,
					'distance_value' => $distance_value,
					'duration_text'  => $duration_text,
					'duration_value' => $duration_value,
				);

				if ( $set_cache ) {
					// Set cache.
					set_transient( $transient, $distancematrix, 1 * DAY_IN_SECONDS );
				}

				return ( '' === $distance_value ) ? false : $distance_array;
			}

			return false;
		}

		/**
		 * Get shipping limitation.
		 *
		 * @param object $package package object.
		 * @param array  $distance distance json.
		 * @return bool
		 */
		public function check_limitation( $package, $distance ) {
			// Check distance array.
			if ( empty( $distance ) || empty( $distance['distance_value'] ) ) {
				$this->show_debug_notice( __( 'Distance value is empty', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
				return false;
			}

			// Check minimum and maximum distance.
			$distance_value = floatval( $distance['distance_value'] ) / 1000;

			if ( 'imperial' === $this->unit_system ) {
				$distance_value = $distance_value / 1609;
			}

			if ( 0 > $distance_value ) {
				$this->show_debug_notice( __( 'Distance value is not valid', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
				return false;
			}

			if ( ! empty( $this->distance_min ) && $this->distance_min > $distance_value ) {
				$this->set_notice( __( 'Your shipping address is below our minimum shipping distance.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
				return false;
			}

			if ( ! empty( $this->distance_max ) && $this->distance_max < $distance_value ) {
				$this->set_notice( __( 'Your shipping address is outside our shipping radius.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
				return false;
			}

			// Check minimum and maximum distance time.
			$duration_value = floatval( $distance['duration_value'] );
			if ( 0 > $duration_value ) {
				$this->show_debug_notice( __( 'Distance duration value is not valid', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
				return false;
			}

			if ( ! empty( $this->distance_time_min ) && (int) $this->distance_time_min * 60 > $duration_value ) {
				$this->set_notice( __( 'The shipping address is below our minimum shipping travel time.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
				return false;
			}

			if ( ! empty( $this->distance_time_max ) && (int) $this->distance_time_max * 60 < $duration_value ) {
				$this->set_notice( __( 'The shipping address is outside our shipping travel time.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
				return false;
			}

			// Check minimum and maximum weight.
			$weight = WC()->cart->cart_contents_weight;
			if ( isset( $weight ) && $weight > 0 ) {
				if ( ! empty( $this->weight_min ) && $weight < $this->weight_min ) {
					$this->set_notice( __( 'The total weight of the products is below the weight we can ship.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
					return false;
				}

				if ( ! empty( $this->weight_max ) && $weight > $this->weight_max ) {
					$this->set_notice( __( 'The total weight of the products is beyond the weight we can ship.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
					return false;
				}
			}

			// Check cart quantity.
			$quantity = WC()->cart->get_cart_contents_count();
			if ( isset( $quantity ) && $quantity > 0 ) {
				if ( ! empty( $this->quantity_min ) && $quantity < $this->quantity_min ) {
					$this->set_notice( __( 'The total quantity of the products is below the quantity we can ship.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
					return false;
				}

				if ( ! empty( $this->quantity_max ) && $quantity > $this->quantity_max ) {
					$this->set_notice( __( 'The total quantity of the products exceeds the quantity we can ship.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
					return false;
				}
			}

			// Check cart total.
			$order_total = $package['cart_subtotal'];
			if ( isset( $order_total ) && $order_total > 0 ) {
				if ( ! empty( $this->total_min ) && $order_total < $this->total_min ) {
					$this->set_notice( __( 'The total cost of the products is below the cost we can ship.', 'distance-rate-shipping-for-woocommerce-powerfulwp' ) );
					return false;
				}
			}

			return true;
		}


		 /**
		  * Get unit system by country.
		  *
		  * @param string $country country.
		  * @return string
		  */
		public function get_country_unit_system( $country ) {
			$array = array( 'gb', 'us', 'lr', 'mm' );
			if ( in_array( strtolower( $country ), $array, true ) ) {
				return 'imperial';
			} else {
				return 'metric';
			}
		}

	}
}
