<?php
/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://powerfulwp.com/
 * @since      1.0.0
 *
 * @package    Distance_Rate_Shipping_For_Woocommerce_Powerfulwp
 * @subpackage Distance_Rate_Shipping_For_Woocommerce_Powerfulwp/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Distance_Rate_Shipping_For_Woocommerce_Powerfulwp
 * @subpackage Distance_Rate_Shipping_For_Woocommerce_Powerfulwp/includes
 * @author     PowerfulWP <apowerfulwp@gmail.com>
 */
class Distance_Rate_Shipping_For_Woocommerce_Powerfulwp {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'DISTANCE_RATE_SHIPPING_FOR_WOOCOMMERCE_POWERFULWP_VERSION' ) ) {
			$this->version = DISTANCE_RATE_SHIPPING_FOR_WOOCOMMERCE_POWERFULWP_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'distance-rate-shipping-for-woocommerce-powerfulwp';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Loader. Orchestrates the hooks of the plugin.
	 * - Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_i18n. Defines internationalization functionality.
	 * - Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Admin. Defines all hooks for the admin area.
	 * - Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-distance-rate-shipping-for-woocommerce-powerfulwp-loader.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-distance-rate-shipping-for-woocommerce-powerfulwp-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-distance-rate-shipping-for-woocommerce-powerfulwp-public.php';

		$this->loader = new Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		// $plugin_i18n = new Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_i18n();

		// $this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

		if ( drsfwp_fs()->is__premium_only() ) {
			if ( drsfwp_fs()->can_use_premium_code() ) {
				$this->loader->add_action( 'woocommerce_shipping_init', $plugin_admin, 'distance_rate_shipping_method' );
				$this->loader->add_filter( 'woocommerce_shipping_methods', $plugin_admin, 'add_distance_rate_shipping_method' );
			}
		}

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action( 'woocommerce_checkout_update_order_review', $plugin_public, 'checkout_update_order_review' );
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Distance_Rate_Shipping_For_Woocommerce_Powerfulwp_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
